     /**
     * \brief JSON Unit Test : Test duplicate entries (keys)
   *
      * Putting a value with the same key in a JSON object should replace the 
      * existing value with the new one.  
      *
   * \author Mihael Schmidt
   * \date   30.01.2012
   */

     H nomain

      *-------------------------------------------------------------------------
      * Prototypes
      *-------------------------------------------------------------------------
     D test_duplicateKeyString...
     D                 PR
     D test_duplicateKeyBoolean...
     D                 PR
     D test_duplicateKeyInteger...
     D                 PR
     D test_duplicateKeyDouble...
     D                 PR
     D test_duplicateKeyDate...
     D                 PR
     D test_duplicateKeyDecimal...
     D                 PR
     
     
      /copy RPGUNIT1,TESTCASE
      /copy 'json/json_h.rpgle'
      /copy 'message_h.rpgle'


     P test_duplicateKeysString...
     P                 B                   export
      *
     D json            S               *
   /free
       json = json_create();
       
       json_putString(json : 'string' : 'Michael');
       iEqual(json_size(json) : 1);
       aEqual(%str(json_getString(json : 'string')) : 'Michael');
       
       json_putString(json : 'string' : 'Mihael');
       iEqual(json_size(json) : 1);
       aEqual(%str(json_getString(json : 'string')) : 'Mihael');
       
       json_dispose(json);
      /end-free
     P                 E
       
       
     P test_duplicateKeysBoolean...
     P                 B                   export
      *
     D json            S               *
   /free
       json = json_create();
         
       json_putBoolean(json : 'bool' : *on);
       iEqual(json_size(json) : 1);
       assert(json_getBoolean(json : 'bool') = *on :
              'Wrong value for added boolean value.');

       json_putBoolean(json : 'bool' : *off);
       iEqual(json_size(json) : 1);
       assert(json_getBoolean(json : 'bool') = *off :
              'Wrong value for added boolean value.');
       
       json_dispose(json);
       
   /end-free
     P                 E
     
     
     P test_duplicateKeysInteger...
     P                 B                   export
      *
     D json            S               *
   /free
       json = json_create();
         
       json_putInt(json : 'int' : 111);
       iEqual(111 : json_getInt(json : 'int'));
       
       json_putInt(json : 'int' : 222);
       iEqual(222 : json_getInt(json : 'int'));
       
       json_dispose(json);
       
   /end-free
     P                 E
     
     
     P test_duplicateKeysDouble...
     P                 B                   export
      *
     D json            S               *
   /free
       json = json_create();
         
       json_putDouble(json : 'double' : 1.11);
       assert(json_getDouble(json : 'double') < 2 : 
              'Wrong value added for double type.');
       
       json_putDouble(json : 'double' : 22.2);
       assert(json_getDouble(json : 'double') > 22.0 :
              'Wrong value added for double type.');
       
       json_dispose(json);
       
   /end-free
     P                 E
     
     
     P test_duplicateKeysDate...
     P                 B                   export
      *
     D json            S               *
     D testDate        S               D
     D testDate2       S               D  
   /free
       testDate = %date();
       testDate2 = %date() + %days(1);

       json = json_create();
         
       json_util_putDate(json : 'date' : testDate);
       assert(testDate = json_util_getDate(json : 'date') : 
              'Wrong value added for date type.');
       
       json_util_putDate(json : 'date' : testDate2);
       assert(testDate2 = json_util_getDate(json : 'date') : 
              'Wrong value added for date type.');
       
       json_dispose(json);
       
   /end-free
     P                 E
    
     P test_duplicateKeysDecimal...
     P                 B                   export
      *
     D json            S               *
   /free
       json = json_create();
         
       json_util_putDecimal(json : 'decimal' : 1.23);
       json_util_putDecimal(json : 'decimal' : 12.34);
       assert(12.34 = json_util_getDecimal(json : 'decimal') : 
              'Wrong value added for date type.');
       
       json_dispose(json);
       
   /end-free
     P                 E
    